@@ -215,7 +215,7 @@ void SceneController::updateElement(OSM::Element e, int level, SceneGraph &sg) c
     state.zoomLevel = d->m_view->zoomLevel();
     state.floorLevel = d->m_view->level();
     state.openingHours = &d->m_openingHours;
-    d->m_styleSheet->evaluate(state, d->m_styleResult);
+    d->m_styleSheet->evaluate(std::move(state), d->m_styleResult);
     for (const auto &result : d->m_styleResult.results()) {
         updateElement(e, level, sg, result);
     }
@@ -387,10 +387,10 @@ void SceneController::updateElement(OSM::Element e, int level, SceneGraph &sg, c
                         }
                         break;
                     case MapCSSDeclaration::IconHeight:
-                        item->iconSize.setHeight(decl->doubleValue()); // TODO percent sizes
+                        item->iconSize.setHeight(PenWidthUtil::penWidth(e, decl, item->iconHeightUnit));
                         break;
                     case MapCSSDeclaration::IconWidth:
-                        item->iconSize.setWidth(decl->doubleValue()); // TODO percent sizes
+                        item->iconSize.setWidth(PenWidthUtil::penWidth(e, decl, item->iconWidthUnit));
                         break;
                     case MapCSSDeclaration::IconColor:
                     {
@@ -427,6 +427,7 @@ void SceneController::updateElement(OSM::Element e, int level, SceneGraph &sg, c
                     iconData.color = d->m_defaultTextColor;
                 }
                 item->icon = d->m_iconLoader.loadIcon(iconData);
+                item->iconOpacity = iconData.color.alphaF();
             }
             if (!item->icon.isNull()) {
                 const auto iconSourceSize = item->icon.availableSizes().at(0);
